==> igniteui-react-16.16.2.tgz: package/esm2015/lib/Toast.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let Toast = /*@__PURE__*/ (() => {
    class Toast extends BaseElement {
        constructor() {
            super(...arguments);
            this.a = new WCNativeHelper();
            this.f = null;
        }
        get b() {
            return this.a;
        }
        get nativeElement() {
            return this.f;
        }
        set nativeElement(a) {
            this.f = a;
            this.a.d = this.f;
        }
        get d() {
            let ret_ = this.b.c("open");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.b.i("open", value_);
        }
        get e() {
            let ret_ = this.b.c("displayTime");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.b.i("displayTime", value_);
        }
        get c() {
            let ret_ = this.b.c("keepOpen");
            return ret_;
        }
        set c(a) {
            let value_ = a;
            this.b.i("keepOpen", value_);
        }
        h() {
            this.nativeElement.hide();
        }
        i() {
            this.nativeElement.show();
        }
        j() {
            this.nativeElement.toggle();
        }
    }
    Toast.$t = /*@__PURE__*/ markType(Toast, 'Toast', BaseElement.$);
    return Toast;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/Toast.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { markType } from "igniteui-react-core";
/**
 * @hidden
 */
export let Toast = /*@__PURE__*/ (() => {
    class Toast extends BaseElement {
        constructor() {
            super(...arguments);
            this.a = new WCNativeHelper();
            this.f = null;
        }
        get b() {
            return this.a;
        }
        get nativeElement() {
            return this.f;
        }
        set nativeElement(a) {
            this.f = a;
            this.a.o = this.f;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get d() {
            let ret_ = this.b.n("open");
            return ret_;
        }
        set d(a) {
            let value_ = a;
            this.b.v("open", value_);
        }
        get e() {
            let ret_ = this.b.n("displayTime");
            return ret_;
        }
        set e(a) {
            let value_ = a;
            this.b.v("displayTime", value_);
        }
        get c() {
            let ret_ = this.b.n("keepOpen");
            return ret_;
        }
        set c(a) {
            let value_ = a;
            this.b.v("keepOpen", value_);
        }
        i() {
            this.nativeElement.hide();
        }
        k() {
            this.nativeElement.show();
        }
        l() {
            this.nativeElement.toggle();
        }
        h() {
            this.nativeElement.connectedCallback();
        }
    }
    Toast.$t = /*@__PURE__*/ markType(Toast, 'Toast', BaseElement.$);
    return Toast;
})();
